"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.organizationmanager.v1.idp.user_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    """Request to get a user by ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to return."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    """Request to list users in a userpool."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to list users in."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "userpool_id", b"userpool_id"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    """Response message for [UserService.List]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.idp.user_pb2.User]:
        """List of users."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.idp.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    """Request to create a new user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    FULL_NAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    FAMILY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    PASSWORD_SPEC_FIELD_NUMBER: builtins.int
    PASSWORD_HASH_FIELD_NUMBER: builtins.int
    IS_ACTIVE_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to create the user in."""
    username: builtins.str
    """Username for the new user."""
    full_name: builtins.str
    """Full name of the user."""
    given_name: builtins.str
    """First name of the user."""
    family_name: builtins.str
    """Last name of the user."""
    email: builtins.str
    """Email address of the user."""
    phone_number: builtins.str
    """Phone number of the user."""
    external_id: builtins.str
    """External identifier for the user."""
    @property
    def password_spec(self) -> global___PasswordSpec:
        """Password specification."""

    @property
    def password_hash(self) -> global___PasswordHash:
        """Password hash."""

    @property
    def is_active(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether the user is active. Default is true."""

    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        username: builtins.str = ...,
        full_name: builtins.str = ...,
        given_name: builtins.str = ...,
        family_name: builtins.str = ...,
        email: builtins.str = ...,
        phone_number: builtins.str = ...,
        password_spec: global___PasswordSpec | None = ...,
        password_hash: global___PasswordHash | None = ...,
        is_active: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        external_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["credentials", b"credentials", "is_active", b"is_active", "password_hash", b"password_hash", "password_spec", b"password_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["credentials", b"credentials", "email", b"email", "external_id", b"external_id", "family_name", b"family_name", "full_name", b"full_name", "given_name", b"given_name", "is_active", b"is_active", "password_hash", b"password_hash", "password_spec", b"password_spec", "phone_number", b"phone_number", "username", b"username", "userpool_id", b"userpool_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["credentials", b"credentials"]) -> typing.Literal["password_spec", "password_hash"] | None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.Create] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user that is being created."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    """Request to update an existing user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    FULL_NAME_FIELD_NUMBER: builtins.int
    GIVEN_NAME_FIELD_NUMBER: builtins.int
    FAMILY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PHONE_NUMBER_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to update."""
    username: builtins.str
    """New username for the user."""
    full_name: builtins.str
    """New full name for the user."""
    given_name: builtins.str
    """New first name for the user."""
    family_name: builtins.str
    """New last name for the user."""
    email: builtins.str
    """New email address for the user."""
    phone_number: builtins.str
    """New phone number for the user."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the user are going to be updated."""

    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        username: builtins.str = ...,
        full_name: builtins.str = ...,
        given_name: builtins.str = ...,
        family_name: builtins.str = ...,
        email: builtins.str = ...,
        phone_number: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "family_name", b"family_name", "full_name", b"full_name", "given_name", b"given_name", "phone_number", b"phone_number", "update_mask", b"update_mask", "user_id", b"user_id", "username", b"username"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.Update] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user that is being updated."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    """Request to delete a user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to delete."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.Delete] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user that is being deleted."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata

@typing.final
class SuspendUserRequest(google.protobuf.message.Message):
    """Request to suspend a user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to suspend."""
    reason: builtins.str
    """Reason for suspending the user."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reason", b"reason", "user_id", b"user_id"]) -> None: ...

global___SuspendUserRequest = SuspendUserRequest

@typing.final
class SuspendUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.Suspend] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user that is being suspended."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___SuspendUserMetadata = SuspendUserMetadata

@typing.final
class ReactivateUserRequest(google.protobuf.message.Message):
    """Request to reactivate a suspended user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to reactivate."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___ReactivateUserRequest = ReactivateUserRequest

@typing.final
class ReactivateUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.Reactivate] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user that is being reactivated."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___ReactivateUserMetadata = ReactivateUserMetadata

@typing.final
class SetOwnPasswordRequest(google.protobuf.message.Message):
    """Request to set the authenticated user's password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_SPEC_FIELD_NUMBER: builtins.int
    OLD_PASSWORD_FIELD_NUMBER: builtins.int
    old_password: builtins.str
    """Current password for verification."""
    @property
    def password_spec(self) -> global___PasswordSpec:
        """New password specification."""

    def __init__(
        self,
        *,
        password_spec: global___PasswordSpec | None = ...,
        old_password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password_spec", b"password_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["old_password", b"old_password", "password_spec", b"password_spec"]) -> None: ...

global___SetOwnPasswordRequest = SetOwnPasswordRequest

@typing.final
class SetOwnPasswordMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.SetOwnPassword] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user whose password is being changed."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___SetOwnPasswordMetadata = SetOwnPasswordMetadata

@typing.final
class SetOwnPasswordResponse(google.protobuf.message.Message):
    """Response for the [UserService.SetOwnPassword] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetOwnPasswordResponse = SetOwnPasswordResponse

@typing.final
class SetOthersPasswordRequest(google.protobuf.message.Message):
    """Request to set another user's password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PASSWORD_SPEC_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user whose password to set."""
    @property
    def password_spec(self) -> global___PasswordSpec:
        """New password specification."""

    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        password_spec: global___PasswordSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password_spec", b"password_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["password_spec", b"password_spec", "user_id", b"user_id"]) -> None: ...

global___SetOthersPasswordRequest = SetOthersPasswordRequest

@typing.final
class SetOthersPasswordMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.SetOthersPassword] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user whose password is being set."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___SetOthersPasswordMetadata = SetOthersPasswordMetadata

@typing.final
class SetOthersPasswordResponse(google.protobuf.message.Message):
    """Response for the [UserService.SetOthersPassword] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetOthersPasswordResponse = SetOthersPasswordResponse

@typing.final
class GeneratePasswordRequest(google.protobuf.message.Message):
    """Request to generate a new password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GeneratePasswordRequest = GeneratePasswordRequest

@typing.final
class GeneratePasswordResponse(google.protobuf.message.Message):
    """Response for the [UserService.GeneratePassword] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_SPEC_FIELD_NUMBER: builtins.int
    @property
    def password_spec(self) -> global___PasswordSpec:
        """Generated password specification."""

    def __init__(
        self,
        *,
        password_spec: global___PasswordSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["password_spec", b"password_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["password_spec", b"password_spec"]) -> None: ...

global___GeneratePasswordResponse = GeneratePasswordResponse

@typing.final
class PasswordSpec(google.protobuf.message.Message):
    """Password specification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_FIELD_NUMBER: builtins.int
    GENERATION_PROOF_FIELD_NUMBER: builtins.int
    password: builtins.str
    """The password string."""
    generation_proof: builtins.str
    """Proof that the password was generated by the system."""
    def __init__(
        self,
        *,
        password: builtins.str = ...,
        generation_proof: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["generation_proof", b"generation_proof", "password", b"password"]) -> None: ...

global___PasswordSpec = PasswordSpec

@typing.final
class PasswordMetadata(google.protobuf.message.Message):
    """Metadata about a user's password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PasswordType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PasswordTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PasswordMetadata._PasswordType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASSWORD_TYPE_UNSPECIFIED: PasswordMetadata._PasswordType.ValueType  # 0
        """The password type is not specified."""
        TEMPORARY: PasswordMetadata._PasswordType.ValueType  # 1
        """Temporary password that must be changed on first use."""
        PERMANENT: PasswordMetadata._PasswordType.ValueType  # 2
        """Permanent password."""

    class PasswordType(_PasswordType, metaclass=_PasswordTypeEnumTypeWrapper):
        """Types of passwords."""

    PASSWORD_TYPE_UNSPECIFIED: PasswordMetadata.PasswordType.ValueType  # 0
    """The password type is not specified."""
    TEMPORARY: PasswordMetadata.PasswordType.ValueType  # 1
    """Temporary password that must be changed on first use."""
    PERMANENT: PasswordMetadata.PasswordType.ValueType  # 2
    """Permanent password."""

    @typing.final
    class PasswordUsage(google.protobuf.message.Message):
        """Information about password usage."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USED_AT_FIELD_NUMBER: builtins.int
        IP_ADDRESS_FIELD_NUMBER: builtins.int
        ip_address: builtins.str
        """IP address from which the password was used."""
        @property
        def used_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
            """Timestamp when the password was last used."""

        def __init__(
            self,
            *,
            used_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            ip_address: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["used_at", b"used_at"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["ip_address", b"ip_address", "used_at", b"used_at"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LAST_USAGE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the password."""
    type: global___PasswordMetadata.PasswordType.ValueType
    """Type of the password."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the password was created."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the password expires."""

    @property
    def last_usage(self) -> global___PasswordMetadata.PasswordUsage:
        """Information about the last usage of the password."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: global___PasswordMetadata.PasswordType.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_usage: global___PasswordMetadata.PasswordUsage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "expires_at", b"expires_at", "last_usage", b"last_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "expires_at", b"expires_at", "id", b"id", "last_usage", b"last_usage", "type", b"type"]) -> None: ...

global___PasswordMetadata = PasswordMetadata

@typing.final
class ConvertToExternalUserRequest(google.protobuf.message.Message):
    """Request to convert a user to use external authentication."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to convert."""
    external_id: builtins.str
    """External identifier to associate with the user."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        external_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_id", b"external_id", "user_id", b"user_id"]) -> None: ...

global___ConvertToExternalUserRequest = ConvertToExternalUserRequest

@typing.final
class ConvertToExternalUserMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.ConvertToExternal] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user being converted."""
    external_id: builtins.str
    """External identifier being associated with the user."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        external_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_id", b"external_id", "user_id", b"user_id"]) -> None: ...

global___ConvertToExternalUserMetadata = ConvertToExternalUserMetadata

@typing.final
class SetPasswordHashRequest(google.protobuf.message.Message):
    """Request to set a password hash for a user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user to set the password hash for."""
    @property
    def hash(self) -> global___PasswordHash:
        """Password hash to set."""

    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        hash: global___PasswordHash | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hash", b"hash"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hash", b"hash", "user_id", b"user_id"]) -> None: ...

global___SetPasswordHashRequest = SetPasswordHashRequest

@typing.final
class SetPasswordHashMetadata(google.protobuf.message.Message):
    """Metadata for the [UserService.SetPasswordHash] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """ID of the user whose password hash is being set."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

global___SetPasswordHashMetadata = SetPasswordHashMetadata

@typing.final
class PasswordHash(google.protobuf.message.Message):
    """Password hash information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PasswordHashType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PasswordHashTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PasswordHash._PasswordHashType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PASSWORD_HASH_TYPE_UNSPECIFIED: PasswordHash._PasswordHashType.ValueType  # 0
        """The password hash type is not specified."""
        AD_MD4: PasswordHash._PasswordHashType.ValueType  # 1
        """Microsoft Active Directory MD4 hash."""

    class PasswordHashType(_PasswordHashType, metaclass=_PasswordHashTypeEnumTypeWrapper):
        """Types of password hashes."""

    PASSWORD_HASH_TYPE_UNSPECIFIED: PasswordHash.PasswordHashType.ValueType  # 0
    """The password hash type is not specified."""
    AD_MD4: PasswordHash.PasswordHashType.ValueType  # 1
    """Microsoft Active Directory MD4 hash."""

    PASSWORD_HASH_FIELD_NUMBER: builtins.int
    PASSWORD_HASH_TYPE_FIELD_NUMBER: builtins.int
    password_hash: builtins.str
    """The password hash string."""
    password_hash_type: global___PasswordHash.PasswordHashType.ValueType
    """Type of the password hash."""
    def __init__(
        self,
        *,
        password_hash: builtins.str = ...,
        password_hash_type: global___PasswordHash.PasswordHashType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["password_hash", b"password_hash", "password_hash_type", b"password_hash_type"]) -> None: ...

global___PasswordHash = PasswordHash

@typing.final
class ResolveExternalIdsRequest(google.protobuf.message.Message):
    """Request to resolve external IDs to internal user IDs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERPOOL_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_IDS_FIELD_NUMBER: builtins.int
    userpool_id: builtins.str
    """ID of the userpool to resolve external IDs in."""
    @property
    def external_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of external IDs to resolve."""

    def __init__(
        self,
        *,
        userpool_id: builtins.str = ...,
        external_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_ids", b"external_ids", "userpool_id", b"userpool_id"]) -> None: ...

global___ResolveExternalIdsRequest = ResolveExternalIdsRequest

@typing.final
class ResolvedUser(google.protobuf.message.Message):
    """Information about a resolved user."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    USERPOOL_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.str
    """Internal user ID."""
    external_id: builtins.str
    """External identifier."""
    userpool_id: builtins.str
    """ID of the userpool the user belongs to."""
    def __init__(
        self,
        *,
        user_id: builtins.str = ...,
        external_id: builtins.str = ...,
        userpool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["external_id", b"external_id", "user_id", b"user_id", "userpool_id", b"userpool_id"]) -> None: ...

global___ResolvedUser = ResolvedUser

@typing.final
class ResolveExternalIdsResponse(google.protobuf.message.Message):
    """Response for the [UserService.ResolveExternalIds] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOLVED_USERS_FIELD_NUMBER: builtins.int
    @property
    def resolved_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResolvedUser]:
        """List of resolved users."""

    def __init__(
        self,
        *,
        resolved_users: collections.abc.Iterable[global___ResolvedUser] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resolved_users", b"resolved_users"]) -> None: ...

global___ResolveExternalIdsResponse = ResolveExternalIdsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.certificatemanager.v1.certificate_content_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CertificateContentServiceStub:
    """A set of methods for managing certificate content."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentRequest,
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentResponse,
    ]
    """Returns chain and private key of the specified certificate."""

    GetEx: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentRequest,
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentResponse,
    ]

class CertificateContentServiceAsyncStub:
    """A set of methods for managing certificate content."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentRequest,
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentResponse,
    ]
    """Returns chain and private key of the specified certificate."""

    GetEx: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentRequest,
        yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentResponse,
    ]

class CertificateContentServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing certificate content."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentResponse, collections.abc.Awaitable[yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetCertificateContentResponse]]:
        """Returns chain and private key of the specified certificate."""

    @abc.abstractmethod
    def GetEx(
        self,
        request: yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentResponse, collections.abc.Awaitable[yandex.cloud.certificatemanager.v1.certificate_content_service_pb2.GetExCertificateContentResponse]]: ...

def add_CertificateContentServiceServicer_to_server(servicer: CertificateContentServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Assistants(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANT_RESULTS_FIELD_NUMBER: builtins.int
    @property
    def assistant_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssistantResult]:
        """List of assistants results"""

    def __init__(
        self,
        *,
        assistant_results: collections.abc.Iterable[global___AssistantResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistant_results", b"assistant_results"]) -> None: ...

global___Assistants = Assistants

@typing.final
class AssistantResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSISTANT_ID_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    assistant_id: builtins.str
    """Assistant id"""
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AssistantFieldResult]:
        """Per-field assistant results"""

    def __init__(
        self,
        *,
        assistant_id: builtins.str = ...,
        results: collections.abc.Iterable[global___AssistantFieldResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["assistant_id", b"assistant_id", "results", b"results"]) -> None: ...

global___AssistantResult = AssistantResult

@typing.final
class AssistantFieldResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIELD_ID_FIELD_NUMBER: builtins.int
    STRING_RESULT_FIELD_NUMBER: builtins.int
    INT_RESULT_FIELD_NUMBER: builtins.int
    FLOAT_RESULT_FIELD_NUMBER: builtins.int
    field_id: builtins.str
    """Assistant result field id"""
    string_result: builtins.str
    """Result as a string"""
    int_result: builtins.int
    """Result as an integer"""
    float_result: builtins.float
    """Result as a floating-point number"""
    def __init__(
        self,
        *,
        field_id: builtins.str = ...,
        string_result: builtins.str = ...,
        int_result: builtins.int = ...,
        float_result: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["field_type", b"field_type", "float_result", b"float_result", "int_result", b"int_result", "string_result", b"string_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["field_id", b"field_id", "field_type", b"field_type", "float_result", b"float_result", "int_result", b"int_result", "string_result", b"string_result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["field_type", b"field_type"]) -> typing.Literal["string_result", "int_result", "float_result"] | None: ...

global___AssistantFieldResult = AssistantFieldResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Payload(google.protobuf.message.Message):
    """A health check payload resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Payload text."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["payload", b"payload", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["payload", b"payload", "text", b"text"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["payload", b"payload"]) -> typing.Literal["text"] | None: ...

global___Payload = Payload



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.speechsense.v1.assistants_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AssistantsServiceStub:
    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsRequest,
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsResponse,
    ]
    """Rpc for listing assistants in a project"""

    ListModels: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsRequest,
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsResponse,
    ]
    """Rpc for listing available assistant models"""

class AssistantsServiceAsyncStub:
    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsRequest,
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsResponse,
    ]
    """Rpc for listing assistants in a project"""

    ListModels: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsRequest,
        yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsResponse,
    ]
    """Rpc for listing available assistant models"""

class AssistantsServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.assistants_service_pb2.ListAssistantsResponse]]:
        """Rpc for listing assistants in a project"""

    @abc.abstractmethod
    def ListModels(
        self,
        request: yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsResponse, collections.abc.Awaitable[yandex.cloud.speechsense.v1.assistants_service_pb2.ListModelsResponse]]:
        """Rpc for listing available assistant models"""

def add_AssistantsServiceServicer_to_server(servicer: AssistantsServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/dataset/v1/dataset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/dataset/v1/dataset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/ai/dataset/v1/dataset.proto\x12\x1ayandex.cloud.ai.dataset.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbd\x05\n\x0b\x44\x61tasetInfo\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x05 \x01(\t\x12>\n\x06status\x18\x06 \x01(\x0e\x32..yandex.cloud.ai.dataset.v1.DatasetInfo.Status\x12\x11\n\ttask_type\x18\x07 \x01(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04rows\x18\n \x01(\x03\x12\x12\n\nsize_bytes\x18\x0b \x01(\x03\x12\x19\n\rcreated_by_id\x18\x0c \x01(\tB\x02\x18\x01\x12\x43\n\x06labels\x18\r \x03(\x0b\x32\x33.yandex.cloud.ai.dataset.v1.DatasetInfo.LabelsEntry\x12\x12\n\ncreated_by\x18\x0e \x01(\t\x12\x12\n\nupdated_by\x18\x0f \x01(\t\x12\x45\n\x10validation_error\x18\x15 \x03(\x0b\x32+.yandex.cloud.ai.dataset.v1.ValidationError\x12\x16\n\x0e\x61llow_data_log\x18\x16 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05J\x04\x08\x10\x10\x15\"P\n\x0fValidationError\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x19\n\x11\x65rror_description\x18\x02 \x01(\t\x12\x13\n\x0brow_numbers\x18\x03 \x03(\x03\"O\n\x13\x44\x61tasetUploadSchema\x12\x11\n\ttask_type\x18\x01 \x01(\t\x12\x15\n\rupload_format\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"2\n\x16\x44\x61tasetFileDownloadUrl\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\tBe\n\x1eyandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.dataset.v1.dataset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomo'
  _globals['_DATASETINFO_LABELSENTRY']._loaded_options = None
  _globals['_DATASETINFO_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DATASETINFO'].fields_by_name['created_by_id']._loaded_options = None
  _globals['_DATASETINFO'].fields_by_name['created_by_id']._serialized_options = b'\030\001'
  _globals['_DATASETINFO']._serialized_start=106
  _globals['_DATASETINFO']._serialized_end=807
  _globals['_DATASETINFO_LABELSENTRY']._serialized_start=657
  _globals['_DATASETINFO_LABELSENTRY']._serialized_end=702
  _globals['_DATASETINFO_STATUS']._serialized_start=704
  _globals['_DATASETINFO_STATUS']._serialized_end=801
  _globals['_VALIDATIONERROR']._serialized_start=809
  _globals['_VALIDATIONERROR']._serialized_end=889
  _globals['_DATASETUPLOADSCHEMA']._serialized_start=891
  _globals['_DATASETUPLOADSCHEMA']._serialized_end=970
  _globals['_DATASETFILEDOWNLOADURL']._serialized_start=972
  _globals['_DATASETFILEDOWNLOADURL']._serialized_end=1022
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.idp import user_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2
from yandex.cloud.organizationmanager.v1.idp import user_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/idp/user_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class UserServiceStub(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/List',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Create',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Delete',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetOwnPassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOwnPassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetOthersPassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOthersPassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Suspend = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Suspend',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Reactivate = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/Reactivate',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.GeneratePassword = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/GeneratePassword',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.FromString,
                _registered_method=True)
        self.GetSelfPasswordMetadata = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/GetSelfPasswordMetadata',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.FromString,
                _registered_method=True)
        self.ConvertToExternal = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/ConvertToExternal',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SetPasswordHash = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/SetPasswordHash',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ResolveExternalIds = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.idp.UserService/ResolveExternalIds',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.FromString,
                _registered_method=True)


class UserServiceServicer(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    def Get(self, request, context):
        """Returns the specified user.

        To get the list of available users, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of users in the specified userpool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a user in the specified userpool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOwnPassword(self, request, context):
        """Sets the password for the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetOthersPassword(self, request, context):
        """Sets the password for another user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Suspend(self, request, context):
        """Suspends the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reactivate(self, request, context):
        """Reactivates a previously suspended user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GeneratePassword(self, request, context):
        """Generates a new password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfPasswordMetadata(self, request, context):
        """Returns metadata about the authenticated user's password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConvertToExternal(self, request, context):
        """Converts a user to use external authentication.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPasswordHash(self, request, context):
        """Sets a password hash for the specified user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveExternalIds(self, request, context):
        """Resolves external IDs to internal user IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetOwnPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOwnPassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetOthersPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.SetOthersPassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Suspend': grpc.unary_unary_rpc_method_handler(
                    servicer.Suspend,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Reactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Reactivate,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GeneratePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.GeneratePassword,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.SerializeToString,
            ),
            'GetSelfPasswordMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfPasswordMetadata,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.SerializeToString,
            ),
            'ConvertToExternal': grpc.unary_unary_rpc_method_handler(
                    servicer.ConvertToExternal,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SetPasswordHash': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPasswordHash,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResolveExternalIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveExternalIds,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.idp.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.idp.UserService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """A set of methods for managing users in the Identity Provider system.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GetUserRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__pb2.User.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/List',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ListUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Create',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.CreateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.UpdateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Delete',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.DeleteUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetOwnPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOwnPassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOwnPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetOthersPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetOthersPassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetOthersPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Suspend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Suspend',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SuspendUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Reactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/Reactivate',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ReactivateUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GeneratePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/GeneratePassword',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.GeneratePasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSelfPasswordMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/GetSelfPasswordMetadata',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.PasswordMetadata.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ConvertToExternal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/ConvertToExternal',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ConvertToExternalUserRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetPasswordHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/SetPasswordHash',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.SetPasswordHashRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResolveExternalIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.idp.UserService/ResolveExternalIds',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_user__service__pb2.ResolveExternalIdsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/application.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/application.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/compute/v1/application.proto\x12\x17yandex.cloud.compute.v1\x1a\x1dyandex/cloud/validation.proto\"\\\n\x06Secret\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x03key\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=256\x12\x1c\n\nversion_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x99\x03\n\x15\x43ontainerSolutionSpec\x12 \n\nproduct_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x62\n\x07secrets\x18\x02 \x03(\x0b\x32;.yandex.cloud.compute.v1.ContainerSolutionSpec.SecretsEntryB\x14\x82\xc8\x31\x05<=100\xb2\xc8\x31\x07\x1a\x05<=100\x12u\n\x0b\x65nvironment\x18\x03 \x03(\x0b\x32?.yandex.cloud.compute.v1.ContainerSolutionSpec.EnvironmentEntryB\x1f\x82\xc8\x31\x05<=100\x8a\xc8\x31\x07<=10000\xb2\xc8\x31\x07\x1a\x05<=100\x1aO\n\x0cSecretsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.yandex.cloud.compute.v1.Secret:\x02\x38\x01\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x01\n\nBackupSpec\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12,\n\x12initial_policy_ids\x18\x02 \x03(\tB\x10\x82\xc8\x31\x04<=50\x8a\xc8\x31\x04\x31-50\x12\x1c\n\x14recovery_from_backup\x18\x03 \x01(\x08\x12\x1c\n\tbackup_id\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12+\n\x18instance_registration_id\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xa2\x01\n\x0b\x41pplication\x12L\n\x12\x63ontainer_solution\x18\x01 \x01(\x0b\x32..yandex.cloud.compute.v1.ContainerSolutionSpecH\x00\x12\x38\n\x0b\x63loudbackup\x18\x02 \x01(\x0b\x32#.yandex.cloud.compute.v1.BackupSpecB\x0b\n\tcontainerBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.application_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_SECRET'].fields_by_name['id']._loaded_options = None
  _globals['_SECRET'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SECRET'].fields_by_name['key']._loaded_options = None
  _globals['_SECRET'].fields_by_name['key']._serialized_options = b'\350\3071\001\212\3101\005<=256'
  _globals['_SECRET'].fields_by_name['version_id']._loaded_options = None
  _globals['_SECRET'].fields_by_name['version_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_options = b'8\001'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['product_id']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['product_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['secrets']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['secrets']._serialized_options = b'\202\3101\005<=100\262\3101\007\032\005<=100'
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['environment']._loaded_options = None
  _globals['_CONTAINERSOLUTIONSPEC'].fields_by_name['environment']._serialized_options = b'\202\3101\005<=100\212\3101\007<=10000\262\3101\007\032\005<=100'
  _globals['_BACKUPSPEC'].fields_by_name['initial_policy_ids']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['initial_policy_ids']._serialized_options = b'\202\3101\004<=50\212\3101\0041-50'
  _globals['_BACKUPSPEC'].fields_by_name['backup_id']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['backup_id']._serialized_options = b'\212\3101\005<=100'
  _globals['_BACKUPSPEC'].fields_by_name['instance_registration_id']._loaded_options = None
  _globals['_BACKUPSPEC'].fields_by_name['instance_registration_id']._serialized_options = b'\212\3101\005<=100'
  _globals['_SECRET']._serialized_start=101
  _globals['_SECRET']._serialized_end=193
  _globals['_CONTAINERSOLUTIONSPEC']._serialized_start=196
  _globals['_CONTAINERSOLUTIONSPEC']._serialized_end=605
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_start=474
  _globals['_CONTAINERSOLUTIONSPEC_SECRETSENTRY']._serialized_end=553
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_start=555
  _globals['_CONTAINERSOLUTIONSPEC_ENVIRONMENTENTRY']._serialized_end=605
  _globals['_BACKUPSPEC']._serialized_start=608
  _globals['_BACKUPSPEC']._serialized_end=788
  _globals['_APPLICATION']._serialized_start=791
  _globals['_APPLICATION']._serialized_end=953
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.address_pb2
import yandex.cloud.vpc.v1.address_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AddressServiceStub:
    """A set of methods for managing Address resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource.

    To get the list of all available Address resources, make a [List] request.
    """

    GetByValue: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource by a given value.

    To get the list of all available Address resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse,
    ]
    """Retrieves the list of Address resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an address in the specified folder and network."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified address."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified address."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse,
    ]
    """List operations for the specified address."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move an address to another folder"""

class AddressServiceAsyncStub:
    """A set of methods for managing Address resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource.

    To get the list of all available Address resources, make a [List] request.
    """

    GetByValue: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        yandex.cloud.vpc.v1.address_pb2.Address,
    ]
    """Returns the specified Address resource by a given value.

    To get the list of all available Address resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse,
    ]
    """Retrieves the list of Address resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an address in the specified folder and network."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified address."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified address."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse,
    ]
    """List operations for the specified address."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move an address to another folder"""

class AddressServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Address resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.GetAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_pb2.Address, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_pb2.Address]]:
        """Returns the specified Address resource.

        To get the list of all available Address resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByValue(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.GetAddressByValueRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_pb2.Address, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_pb2.Address]]:
        """Returns the specified Address resource by a given value.

        To get the list of all available Address resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.ListAddressesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_service_pb2.ListAddressesResponse]]:
        """Retrieves the list of Address resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.CreateAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an address in the specified folder and network."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.UpdateAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified address."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.DeleteAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified address."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.address_service_pb2.ListAddressOperationsResponse]]:
        """List operations for the specified address."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.address_service_pb2.MoveAddressRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move an address to another folder"""

def add_AddressServiceServicer_to_server(servicer: AddressServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.video.v1 import stream_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2
from yandex.cloud.video.v1 import stream_service_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/video/v1/stream_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StreamServiceStub(object):
    """Stream management service.
    Provides methods for creating, retrieving, updating, and deleting live streams,
    as well as managing stream-related operations
    such as publishing, stopping, and generating playback URLs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/Get',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.GetStreamRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2.Stream.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/List',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsResponse.FromString,
                _registered_method=True)
        self.BatchGet = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/BatchGet',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/Create',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.CreateStreamRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/Update',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.UpdateStreamRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/Delete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.DeleteStreamRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.BatchDelete = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/BatchDelete',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchDeleteStreamsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.PerformAction = channel.unary_unary(
                '/yandex.cloud.video.v1.StreamService/PerformAction',
                request_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.PerformStreamActionRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class StreamServiceServicer(object):
    """Stream management service.
    Provides methods for creating, retrieving, updating, and deleting live streams,
    as well as managing stream-related operations
    such as publishing, stopping, and generating playback URLs.
    """

    def Get(self, request, context):
        """Retrieves detailed information about a specific stream by its ID.
        Returns all stream metadata, status, and related information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all streams in a specific channel with pagination support.
        Results can be filtered and sorted using the provided parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGet(self, request, context):
        """Retrieves multiple streams by their IDs in a specific channel in a single request.
        This is more efficient than making multiple Get requests when retrieving several streams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new stream in the specified channel.
        Streams can be created as on-demand (starting when a signal appears)
        or scheduled (starting and finishing at specified time).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing stream's metadata and settings.
        Only fields specified in the field_mask will be updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a specific stream by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDelete(self, request, context):
        """Deletes multiple streams in a specific channel in a single request.
        This is more efficient than making multiple Delete requests when removing several streams.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformAction(self, request, context):
        """Performs a specific action on a stream, such as publishing or stopping.
        Actions change the stream's state without modifying its content or metadata.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StreamServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.GetStreamRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2.Stream.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsResponse.SerializeToString,
            ),
            'BatchGet': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGet,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.CreateStreamRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.UpdateStreamRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.DeleteStreamRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'BatchDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDelete,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchDeleteStreamsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'PerformAction': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformAction,
                    request_deserializer=yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.PerformStreamActionRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.video.v1.StreamService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.video.v1.StreamService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class StreamService(object):
    """Stream management service.
    Provides methods for creating, retrieving, updating, and deleting live streams,
    as well as managing stream-related operations
    such as publishing, stopping, and generating playback URLs.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/Get',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.GetStreamRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__pb2.Stream.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/List',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.ListStreamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/BatchGet',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsRequest.SerializeToString,
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchGetStreamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/Create',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.CreateStreamRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/Update',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.UpdateStreamRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/Delete',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.DeleteStreamRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/BatchDelete',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.BatchDeleteStreamsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PerformAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.video.v1.StreamService/PerformAction',
            yandex_dot_cloud_dot_video_dot_v1_dot_stream__service__pb2.PerformStreamActionRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.clouddesktop.v1 import desktop_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__pb2
from yandex.cloud.clouddesktop.v1 import desktop_service_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/clouddesktop/v1/desktop_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DesktopServiceStub(object):
    """A set of methods for managing desktop resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Get',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetDesktopRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__pb2.Desktop.FromString,
                _registered_method=True)
        self.GetRdpFile = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/GetRdpFile',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetRdpFileRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RdpFileResponse.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/List',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsResponse.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Create',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.CreateDesktopRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.UpdateProperties = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/UpdateProperties',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdatePropertiesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Delete',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.DeleteDesktopRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ResetPassword = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/ResetPassword',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordResponse.FromString,
                _registered_method=True)
        self.Restart = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Restart',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RestartRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Update',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Start = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Start',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StartRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Stop = channel.unary_unary(
                '/yandex.cloud.clouddesktop.v1.api.DesktopService/Stop',
                request_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StopRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class DesktopServiceServicer(object):
    """A set of methods for managing desktop resources.
    """

    def Get(self, request, context):
        """Returns the specified desktop resource.

        To get the list of available desktops, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRdpFile(self, request, context):
        """Returns a RDP file for the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of desktop resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Returns list of the operations for the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates desktop in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateProperties(self, request, context):
        """Updates desktop properties.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetPassword(self, request, context):
        """Reset password
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Restart(self, request, context):
        """Restart the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Sync desktop with group configuration
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Start the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stop the specified desktop.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DesktopServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetDesktopRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__pb2.Desktop.SerializeToString,
            ),
            'GetRdpFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRdpFile,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetRdpFileRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RdpFileResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.CreateDesktopRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateProperties': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateProperties,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdatePropertiesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.DeleteDesktopRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ResetPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetPassword,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordResponse.SerializeToString,
            ),
            'Restart': grpc.unary_unary_rpc_method_handler(
                    servicer.Restart,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RestartRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StartRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StopRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.clouddesktop.v1.api.DesktopService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.clouddesktop.v1.api.DesktopService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DesktopService(object):
    """A set of methods for managing desktop resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Get',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetDesktopRequest.SerializeToString,
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__pb2.Desktop.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRdpFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/GetRdpFile',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.GetRdpFileRequest.SerializeToString,
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RdpFileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/List',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsRequest.SerializeToString,
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/ListOperations',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ListDesktopOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Create',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.CreateDesktopRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateProperties(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/UpdateProperties',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdatePropertiesRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Delete',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.DeleteDesktopRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ResetPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/ResetPassword',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.ResetPasswordResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Restart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Restart',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.RestartRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Update',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.UpdateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Start',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StartRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.clouddesktop.v1.api.DesktopService/Stop',
            yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__service__pb2.StopRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AsymmetricEncryptionAlgorithm:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AsymmetricEncryptionAlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AsymmetricEncryptionAlgorithm.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ASYMMETRIC_ENCRYPTION_ALGORITHM_UNSPECIFIED: _AsymmetricEncryptionAlgorithm.ValueType  # 0
    RSA_2048_ENC_OAEP_SHA_256: _AsymmetricEncryptionAlgorithm.ValueType  # 1
    """RSA-2048 encryption with OAEP padding and SHA-256"""
    RSA_3072_ENC_OAEP_SHA_256: _AsymmetricEncryptionAlgorithm.ValueType  # 2
    """RSA-3072 encryption with OAEP padding and SHA-256"""
    RSA_4096_ENC_OAEP_SHA_256: _AsymmetricEncryptionAlgorithm.ValueType  # 3
    """RSA-4096 encryption with OAEP padding and SHA-256"""

class AsymmetricEncryptionAlgorithm(_AsymmetricEncryptionAlgorithm, metaclass=_AsymmetricEncryptionAlgorithmEnumTypeWrapper):
    """Supported asymmetric encryption algorithms."""

ASYMMETRIC_ENCRYPTION_ALGORITHM_UNSPECIFIED: AsymmetricEncryptionAlgorithm.ValueType  # 0
RSA_2048_ENC_OAEP_SHA_256: AsymmetricEncryptionAlgorithm.ValueType  # 1
"""RSA-2048 encryption with OAEP padding and SHA-256"""
RSA_3072_ENC_OAEP_SHA_256: AsymmetricEncryptionAlgorithm.ValueType  # 2
"""RSA-3072 encryption with OAEP padding and SHA-256"""
RSA_4096_ENC_OAEP_SHA_256: AsymmetricEncryptionAlgorithm.ValueType  # 3
"""RSA-4096 encryption with OAEP padding and SHA-256"""
global___AsymmetricEncryptionAlgorithm = AsymmetricEncryptionAlgorithm

@typing.final
class AsymmetricEncryptionKey(google.protobuf.message.Message):
    """An asymmetric KMS key that may contain several versions of the cryptographic material."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AsymmetricEncryptionKey._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: AsymmetricEncryptionKey._Status.ValueType  # 0
        CREATING: AsymmetricEncryptionKey._Status.ValueType  # 1
        """The key is being created."""
        ACTIVE: AsymmetricEncryptionKey._Status.ValueType  # 2
        """The key is active and can be used for encryption and decryption or signature and verification.
        Can be set to INACTIVE using the [AsymmetricKeyService.Update] method.
        """
        INACTIVE: AsymmetricEncryptionKey._Status.ValueType  # 3
        """The key is inactive and unusable.
        Can be set to ACTIVE using the [AsymmetricKeyService.Update] method.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: AsymmetricEncryptionKey.Status.ValueType  # 0
    CREATING: AsymmetricEncryptionKey.Status.ValueType  # 1
    """The key is being created."""
    ACTIVE: AsymmetricEncryptionKey.Status.ValueType  # 2
    """The key is active and can be used for encryption and decryption or signature and verification.
    Can be set to INACTIVE using the [AsymmetricKeyService.Update] method.
    """
    INACTIVE: AsymmetricEncryptionKey.Status.ValueType  # 3
    """The key is inactive and unusable.
    Can be set to ACTIVE using the [AsymmetricKeyService.Update] method.
    """

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ENCRYPTION_ALGORITHM_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the key."""
    folder_id: builtins.str
    """ID of the folder that the key belongs to."""
    name: builtins.str
    """Name of the key."""
    description: builtins.str
    """Description of the key."""
    status: global___AsymmetricEncryptionKey.Status.ValueType
    """Current status of the key."""
    encryption_algorithm: global___AsymmetricEncryptionAlgorithm.ValueType
    """Asymmetric Encryption Algorithm ID."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the key"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the key was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the key as `key:value` pairs. Maximum 64 per key."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___AsymmetricEncryptionKey.Status.ValueType = ...,
        encryption_algorithm: global___AsymmetricEncryptionAlgorithm.ValueType = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "encryption_algorithm", b"encryption_algorithm", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "status", b"status"]) -> None: ...

global___AsymmetricEncryptionKey = AsymmetricEncryptionKey
